﻿using System.Windows;
using System.Windows.Controls;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;
using System;
using System.Threading;

namespace DisplayASimpleMapForWPF
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void WpfMap_Loaded(object sender, RoutedEventArgs e)
        {
            wpfMap1.MapUnit = GeographyUnit.DecimalDegree;
            wpfMap1.CurrentExtent = new RectangleShape(0, 50, 50, 0);

            InMemoryFeatureLayer inMemoryLayer1 = new InMemoryFeatureLayer();
            inMemoryLayer1.ZoomLevelSet.ZoomLevel01.DefaultPointStyle.SymbolPen = new GeoPen(GeoColor.FromArgb(255, GeoColor.StandardColors.Green), 8);
            inMemoryLayer1.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            InMemoryFeatureLayer inMemoryLayer2 = new InMemoryFeatureLayer();
            inMemoryLayer2.ZoomLevelSet.ZoomLevel01.DefaultPointStyle.SymbolPen = new GeoPen(GeoColor.FromArgb(255, GeoColor.StandardColors.Red), 8);
            inMemoryLayer2.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            LayerOverlay inmemoryOverlay = new LayerOverlay();
            inmemoryOverlay.TileType = TileType.SingleTile;
            inmemoryOverlay.Layers.Add(new BackgroundLayer(new GeoSolidBrush(GeoColor.StandardColors.White)));
            inmemoryOverlay.Layers.Add("InMemoryFeatureLayer1", inMemoryLayer1);
            inmemoryOverlay.Layers.Add("InMemoryFeatureLayer2", inMemoryLayer2);
            wpfMap1.Overlays.Add("InmemoryOverlay", inmemoryOverlay);

            wpfMap1.Refresh();

            Thread thread = new Thread(new ThreadStart(BackgroundThread));
            thread.Start();
        }

        void BackgroundThread()
        {
            for (int i = 0; i < 1000; i++)
            {
                AddShapeToLayer1();
                AddShapeToLayer2();
                if (i == 0)
                {
                    wpfMap1.Dispatcher.Invoke(new Action(() => wpfMap1.CenterAt(new PointShape(50, 50))));
                }
                wpfMap1.Dispatcher.Invoke(new Action(() => wpfMap1.Refresh()));
                Thread.Sleep(10);
            }
            wpfMap1.Dispatcher.Invoke(new Action(() => wpfMap1.Refresh()));
        }

        Random random = new Random();

        private void AddShapeToLayer1()
        {
            InMemoryFeatureLayer layer1 = wpfMap1.FindFeatureLayer("InMemoryFeatureLayer1") as InMemoryFeatureLayer;
            layer1.Open();
            PointShape point = new PointShape();
            point.X = random.Next(100);
            point.Y = random.Next(100);
            layer1.InternalFeatures.Add(new Feature(point));
            layer1.Close();
        }

        private void AddShapeToLayer2()
        {
            InMemoryFeatureLayer layer2 = wpfMap1.FindFeatureLayer("InMemoryFeatureLayer2") as InMemoryFeatureLayer;
            layer2.Open();
            PointShape point = new PointShape();
            point.X = random.Next(100);
            point.Y = random.Next(100);
            layer2.InternalFeatures.Add(new Feature(point));
            layer2.Close();
        }
    }
}
